==> haskell-foldl-1.4.12-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 foldl
version:              1.4.12
visibility:           public
id:                   foldl-1.4.12-FD7lPU86KKqB9jTpsviYd0
key:                  foldl-1.4.12-FD7lPU86KKqB9jTpsviYd0
license:              BSD-3-Clause
copyright:            2013 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.

category:             Control
abi:                  b29abcc4c3d08972791a9946baf8bf56
exposed:              True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.Text
    Control.Scanl

hidden-modules:
    Control.Foldl.Optics Control.Foldl.Internal
    Control.Foldl.Util.Vector Control.Foldl.Util.MVector

import-dirs:          /usr/lib/ghc-9.0.2/site-local/foldl-1.4.12
library-dirs:         /usr/lib/ghc-9.0.2/site-local/foldl-1.4.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-foldl
hs-libraries:         HSfoldl-1.4.12-FD7lPU86KKqB9jTpsviYd0
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    comonad-5.0.8-EaTlEN7Ks86AipwN0rGEbx containers-0.6.4.1
    contravariant-1.5.5-FtJyCLyWfutGN2UWoJs8qd
    hashable-1.4.0.0-2kZOg714Ij1LrJRy9uadpc
    primitive-0.7.3.0-2pPolq6nwvBJPBD9Qp8BKd
    profunctors-5.6.2-Jgj6tgZNklHAmf2rghAaCI
    random-1.2.1-5U0YGsolfl8IMYyd70msQI
    semigroupoids-5.3.7-9AddbSUosbAKI3E20JZJM7 text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.17.0-JNy7TYCGdCY8DuvJZDrDzh
    vector-0.12.3.1-AXj2d06Eo3d7wImXBgXWju

haddock-interfaces:   /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html:         /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-foldl-1.4.12-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 foldl
version:              1.4.12
visibility:           public
id:                   foldl-1.4.12-3Gu2riHU4k3Gx4IruSLmGP
key:                  foldl-1.4.12-3Gu2riHU4k3Gx4IruSLmGP
license:              BSD-3-Clause
copyright:            2013 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.

category:             Control
abi:                  9fcc3310fa0daecb086a9744d71c01d9
exposed:              True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.Text
    Control.Scanl

hidden-modules:
    Control.Foldl.Optics Control.Foldl.Internal
    Control.Foldl.Util.Vector Control.Foldl.Util.MVector

import-dirs:          /usr/lib/ghc-9.0.2/site-local/foldl-1.4.12
library-dirs:         /usr/lib/ghc-9.0.2/site-local/foldl-1.4.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-foldl
hs-libraries:         HSfoldl-1.4.12-3Gu2riHU4k3Gx4IruSLmGP
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    comonad-5.0.8-5DtAKlunqGU838MSR0dF9T containers-0.6.4.1
    contravariant-1.5.5-FtJyCLyWfutGN2UWoJs8qd
    hashable-1.4.0.0-3tT111jpna6LV0O1fUcNNF
    primitive-0.7.3.0-HuG2rWCCHI33cxmpgTscxY
    profunctors-5.6.2-AFknL06hytbHSmoORnDIAf
    random-1.2.1-5J0ZhMIxycI8iOnaSxybOH
    semigroupoids-5.3.7-EaGq8CldlFfGZtAHqVYzyh text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.17.0-4bcRecgfIOjL5KIXJoFyIi
    vector-0.12.3.1-K551lzEJJcR9600hgrx2VO

haddock-interfaces:   /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html:         /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
